==> dl.php?src=linea21_1_3_1.zip: linea21/languages/it/lang_theme.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	confirmation
*  	*/
$lang['theme']['name']="tema";
$lang['theme']['confirm_add'] = "Aggiunta di un tema avvenuta con successo\n";
$lang['theme']['confirm_mod'] = "Modifica del tema avvenuta con successo\n";
$lang['theme']['confirm_sup'] ="Eliminazione del tema avvenuta con successo\n";

/*	nommage rubrique add / mod /det
*  	*/
$lang['theme']['add_title']="Inserimento delle informazioni del nuovo ".$lang['theme']['name'];
$lang['theme']['mod_title']="Modifica delle informazioni di ".$lang['theme']['name'];


/*	nommage rubrique module
*  	*/
$lang['theme']['add']= "Aggiunta di un ".$lang['theme']['name'];
$lang['theme']['mod']= "Modifica di un ".$lang['theme']['name'];
$lang['theme']['sup']= "Eliminazione di un ".$lang['theme']['name'];
$lang['theme']['det']= "Dettali di ".$lang['theme']['name'];
$lang['theme']['list']= "Consultazione dei temi";
$lang['sdtheme']['det']= "Dettagli del tema Sviluppo Sostenibile";

/*	nommage élément rubrique
*  	*/
$lang['theme']['is_root']="Tema principale";
$lang['theme']['denomination']="Denominazione di ".$lang['theme']['name'];
$lang['theme']['sdtheme']="Tema Sviluppo Sostenibile";
$lang['theme']['photouri']="Immagine associata al ".$lang['theme']['name'];
$lang['theme']['statut']="Status del ".$lang['theme']['name'];

$lang['theme']['description']="Descrizione del ".$lang['theme']['name'];
$lang['theme']['description_all']="Descrizione comune all'insieme dei moduli.";
$lang['theme']['desc_all']="Descrizione del tema (comune).";
$lang['theme']['description_det']="Descrizione del ".$lang['theme']['name']." per modulo.";
$lang['theme']['desc_det_project']="Progetti  (descrizione)";
$lang['theme']['desc_det_dashboard']="Pannello IDD  (descrizione)";
$lang['theme']['desc_det_publication']="Cartelle (descrizione)";
$lang['theme']['desc_det_news']="News (descrizione)";
$lang['theme']['desc_det_workshop']="Gruppi di lavoro (descrizione)";
$lang['theme']['desc_det_forum']="Forum (descrizione)";

/*	nommage rubrique sup
*  	*/
$lang['theme']['sup_massd']= "Eliminare le risorse allegate a questo tema";
$lang['theme']['sup_massm']= "Collegare a un altro tema le risorse associate a questo tema"; 
$lang['theme']['sup_transfert']= "Tema di trasferimento"; 

/*	nommage quickbox
*  	*/
$lang['theme']['qb_titleadd']=" ultime aggiunte effettuate";
$lang['theme']['qb_titlemod']=" ultime modifiche effettuate";
$lang['theme']['qb_titlesup']=" ultime eliminazioni effettuate";

/*	messages
*  	*/
$lang['theme']['object_notdenomination']="Devi tassativamente inserire un nome per il tema.";
$lang['theme']['object_notSDtheme']="Devi tassativamente associare a il tema a una tematica Sviluppo Sostenibile.";
$lang['theme']['object_notdesc_completed']="Devi tassativamente inserire la descrizione per ogni tema.";
$lang['theme']['object_notstatus']="Devi tassativamente precisare lo status del tema.";
$lang['theme']['sup_nomethod']="Devi tassativamente scegliere un metodo di eliminazione!";
$lang['theme']['sup_notheme']="Devi tassativamente scegliere un tema di trasferimento!";
$lang['theme']['sup_mass_delete']="Attenzione l'eliminazione di questo tema comporterà la soppressione delle risorse associate.";
$lang['theme']['sup_mass_modify']="Scegliendo un trasferimento, tutte le risorse associate al tema che desideri eliminare saranno associate al nuovo tema scelto.";

/*	rubrique d'aide
*  	*/
$lang['theme']['help_add1']="Per aggiungere un tema, devi inserire ciascuno dei suoi parametri nel modulo qui sotto";
$lang['theme']['help_add2']="Devi tassativamente associare un tema generale al tema in corso di creazione";
$lang['theme']['help_add3']="Dopo aver convalidato il modulo d'aggiunta, controlla i parametri d'aggiunta nel riepilogo";
$lang['theme']['help_add4']="Se il riepilogo non ti soddisfa, puoi cliccare su 'modifica i parametri' per modificarlo";


$lang['theme']['help_list1']="Per visualizzare un tema nel dettaglio, clicca sul nome del tema medesimo";
$lang['theme']['help_list2']="Puoi eliminare un tema cliccando sull'icona di eliminazione associata";
$lang['theme']['help_list3']="Puoi modificare un tema cliccando sull'icona di modifica associata";
$lang['theme']['help_list4']="Per aggiungere un tema, clicca sul link \"aggiungere un tema\" nella barra degli strumenti";
$lang['theme']['help_list5']="Puoi effettuare una ricerca di tema in ogni momento cliccando su 'ricerca'";


$lang['theme']['help_mod1']="Puoi modificare ciascuno dei parametri nel modulo qui sotto";
$lang['theme']['help_mod2']="Dopo aver convalidato il modulo di modifica, controlla le informazioni inserite nel riepilogo";
$lang['theme']['help_mod3']="Se il riepilogo non ti soddisfa, puoi cliccare su 'modifica i parametri' per modificare nuovamente i dati";


$lang['theme']['help_det1']="Per visualizzare il dettaglio del tema generale associato al tema dettagliato, clicca sul nome di quest'ultimo";
$lang['theme']['help_det2']="Puoi eliminare questo tema cliccando sull'icona di eliminazione associata";
$lang['theme']['help_det3']="Puoi modificare questo tema cliccando sull'icona di modifica associata";
$lang['sdtheme']['help_det1']="Il tema attuale è un tema radice (componente di Sviluppo Sostenibile). Non è, di conseguenza, né pubblicabile né eliminabile.";


$lang['theme']['help_sup1']="Devi tassativamente scegliere un metodo di cancellazione per eliminare un tema";
$lang['theme']['help_sup2']="Per ragioni di sicurezza, devi copiare il codice di sicurezza nel campo previsto a questo scopo al fine di convalidare l'eliminazione";
$lang['theme']['help_sup3']="Attenzione l'eliminazione del tema selezionato comporterà numerosi cambiamenti nell'insieme dei moduli, questa eliminazione è riservata agli amministratori esperti";

?>

==> dl.php?src=linea21_1_4.zip: linea21/languages/it/lang_theme.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	confirmation
 *  	*/
$lang['theme']['name']="tema";
$lang['theme']['confirm_add'] = "Aggiunta di un tema avvenuta con successo\n";
$lang['theme']['confirm_mod'] = "Modifica del tema avvenuta con successo\n";
$lang['theme']['confirm_sup'] ="Eliminazione del tema avvenuta con successo\n";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['theme']['add_title']="Inserimento delle informazioni del nuovo ".$lang['theme']['name'];
$lang['theme']['mod_title']="Modifica delle informazioni di ".$lang['theme']['name'];


/*	nommage rubrique module
 *  	*/
$lang['theme']['add']= "Aggiunta di un ".$lang['theme']['name'];
$lang['theme']['mod']= "Modifica di un ".$lang['theme']['name'];
$lang['theme']['sup']= "Eliminazione di un ".$lang['theme']['name'];
$lang['theme']['det']= "Dettali di ".$lang['theme']['name'];
$lang['theme']['list']= "Consultazione dei temi";
$lang['sdtheme']['det']= "Dettagli del tema principale";

/*	nommage élément rubrique
 *  	*/
$lang['theme']['is_root']="Tema principale ?";
$lang['theme']['denomination']="Denominazione di ".$lang['theme']['name'];
$lang['theme']['sdtheme']="Tema principale";
$lang['theme']['photouri']="Immagine associata al ".$lang['theme']['name'];
$lang['theme']['statut']="Status del ".$lang['theme']['name'];

$lang['theme']['description']="Descrizione del ".$lang['theme']['name'];
$lang['theme']['description_all']="Descrizione comune all'insieme dei moduli.";
$lang['theme']['desc_all']="Descrizione del tema (comune).";
$lang['theme']['description_det']="Descrizione del ".$lang['theme']['name']." per modulo.";
$lang['theme']['desc_det_project']="Progetti  (descrizione)";
$lang['theme']['desc_det_dashboard']="Pannello IDD  (descrizione)";
$lang['theme']['desc_det_publication']="Cartelle (descrizione)";
$lang['theme']['desc_det_news']="News (descrizione)";
$lang['theme']['desc_det_workshop']="Gruppi di lavoro (descrizione)";
$lang['theme']['desc_det_forum']="Forum (descrizione)";

/*	nommage rubrique sup
 *  	*/
$lang['theme']['sup_massd']= "Eliminare le risorse allegate a questo tema";
$lang['theme']['sup_massm']= "Collegare a un altro tema le risorse associate a questo tema";
$lang['theme']['sup_transfert']= "Tema di trasferimento";

/*	nommage quickbox
 *  	*/
$lang['theme']['qb_titleadd']=" ultime aggiunte effettuate";
$lang['theme']['qb_titlemod']=" ultime modifiche effettuate";
$lang['theme']['qb_titlesup']=" ultime eliminazioni effettuate";

/*	messages
 *  	*/
$lang['theme']['object_notdenomination']="Devi tassativamente inserire un nome per il tema.";
$lang['theme']['object_notSDtheme']="Devi tassativamente associare a il tema a una tematica Sviluppo Sostenibile.";
$lang['theme']['object_notdesc_completed']="Devi tassativamente inserire la descrizione per ogni tema.";
$lang['theme']['object_notstatus']="Devi tassativamente precisare lo status del tema.";
$lang['theme']['sup_nomethod']="Devi tassativamente scegliere un metodo di eliminazione!";
$lang['theme']['sup_notheme']="Devi tassativamente scegliere un tema di trasferimento!";
$lang['theme']['sup_mass_delete']="Attenzione l'eliminazione di questo tema comporterà la soppressione delle risorse associate.";
$lang['theme']['sup_mass_modify']="Scegliendo un trasferimento, tutte le risorse associate al tema che desideri eliminare saranno associate al nuovo tema scelto.";

/*	rubrique d'aide
 *  	*/
$lang['theme']['help_add1']="Per aggiungere un tema, devi inserire ciascuno dei suoi parametri nel modulo qui sotto";
$lang['theme']['help_add2']="Devi tassativamente associare un tema generale al tema in corso di creazione";
$lang['theme']['help_add3']="Dopo aver convalidato il modulo d'aggiunta, controlla i parametri d'aggiunta nel riepilogo";
$lang['theme']['help_add4']="Se il riepilogo non ti soddisfa, puoi cliccare su 'modifica i parametri' per modificarlo";


$lang['theme']['help_list1']="Per visualizzare un tema nel dettaglio, clicca sul nome del tema medesimo";
$lang['theme']['help_list2']="Puoi eliminare un tema cliccando sull'icona di eliminazione associata";
$lang['theme']['help_list3']="Puoi modificare un tema cliccando sull'icona di modifica associata";
$lang['theme']['help_list4']="Per aggiungere un tema, clicca sul link \"aggiungere un tema\" nella barra degli strumenti";
$lang['theme']['help_list5']="Puoi effettuare una ricerca di tema in ogni momento cliccando su 'ricerca'";


$lang['theme']['help_mod1']="Puoi modificare ciascuno dei parametri nel modulo qui sotto";
$lang['theme']['help_mod2']="Dopo aver convalidato il modulo di modifica, controlla le informazioni inserite nel riepilogo";
$lang['theme']['help_mod3']="Se il riepilogo non ti soddisfa, puoi cliccare su 'modifica i parametri' per modificare nuovamente i dati";


$lang['theme']['help_det1']="Per visualizzare il dettaglio del tema generale associato al tema dettagliato, clicca sul nome di quest'ultimo";
$lang['theme']['help_det2']="Puoi eliminare questo tema cliccando sull'icona di eliminazione associata";
$lang['theme']['help_det3']="Puoi modificare questo tema cliccando sull'icona di modifica associata";
$lang['sdtheme']['help_det1']="Il tema attuale è un tema radice (componente di Sviluppo Sostenibile). Non è, di conseguenza, né pubblicabile né eliminabile.";


$lang['theme']['help_sup1']="Devi tassativamente scegliere un metodo di cancellazione per eliminare un tema";
$lang['theme']['help_sup2']="Per ragioni di sicurezza, devi copiare il codice di sicurezza nel campo previsto a questo scopo al fine di convalidare l'eliminazione";
$lang['theme']['help_sup3']="Attenzione l'eliminazione del tema selezionato comporterà numerosi cambiamenti nell'insieme dei moduli, questa eliminazione è riservata agli amministratori esperti";

?>
